@@ -323,8 +323,8 @@ const ISC_INFO_TRA_ACCESS: u32 = 9;
 const ISC_INFO_TRA_LOCK_TIMEOUT: u32 = 10;
 
 macro_rules! debug_print {
-//    ($( $args:expr ),*) => { println!( $( $args ),* ); }
-    ($( $args:expr ),*) => {}
+    //    ($( $args:expr ),*) => { println!( $( $args ),* ); }
+    ($( $args:expr ),*) => {};
 }
 
 fn info_sql_select_describe_vars() -> [u8; 13] {
@@ -635,7 +635,7 @@ impl WireProtocol {
         let server_public =
             utils::big_int_from_hex_string(&utils::bytes_to_str(&data[4 + ln..]).as_bytes());
         let (auth_data, session_key) = srp::get_client_proof(
-            username,
+            &username.to_uppercase(),
             password,
             servre_salt,
             client_public,
